package com.vp.plugin.sample.modelviewchecker.ui;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.table.*;

import com.vp.plugin.model.*;
import com.vp.plugin.sample.modelviewchecker.ui.ModelViewTableModel.*;
import com.vp.plugin.view.*;

public class ModelViewDialog implements IDialogHandler {

	private IDialog _dialog;
	private final JComponent _component;
	private final ModelViewTableModel _tableModel;
	
	public ModelViewDialog(IModelElement[] models) {
		this._tableModel = new ModelViewTableModel(models);
		JTable table = new JTable(_tableModel);
		
		JButton deleteButton = new JButton("Delete");
		deleteButton.setMnemonic('d');
		deleteButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent aE) {
				delete();
			}
		});
		
		JButton closeButton = new JButton("Close");
		closeButton.setMnemonic('c');
		closeButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent aE) {
				close();
			}
		});
		
		JPanel pane = new JPanel(new BorderLayout());
		JPanel buttonPane = new JPanel(new FlowLayout(FlowLayout.RIGHT));
		buttonPane.add(deleteButton);
		buttonPane.add(closeButton);
		
		pane.add(new JScrollPane(table), BorderLayout.CENTER);
		pane.add(buttonPane, BorderLayout.SOUTH);
		
		this._component = pane;
		
		this.fitColumnWidth(table, ModelViewTableModel.COLUMN_SELECTED, "Selected");
	}

	public boolean canClosed() {
		return true;
	}

	public Component getComponent() {
		return this._component;
	}

	public void prepare(IDialog dialog) {
		this._dialog = dialog;
		dialog.setTitle("Delete No View Models");
		dialog.setSize(500, 400);
	}

	public void shown() {
	}
	
	
	private void delete() {
		Data[] values = this._tableModel.getValues();
		int count = values == null ? 0 : values.length;
		for (int i = 0; i < count; i++) {
			Data value = values[i];
			if (value.isSelected()) {
				value.model.delete();
			}
		}
		this.close();
	}
	private void close() {
		this._dialog.close();
	}

	private void fitColumnWidth(JTable table, int columnIndex, String text) {
		Component component = table.getTableHeader()
			.getDefaultRenderer().getTableCellRendererComponent(
				table, null, false, false, 0, columnIndex
			);
		Insets insets = null;
		if (component instanceof JComponent) {
			insets = ((JComponent) component).getInsets();
		}
		if (insets == null) {
			insets = new Insets(0, 0, 0, 05);
		}
		TableColumn column = table.getColumnModel().getColumn(columnIndex);
		if (text == null) {
			text = table.getColumnName(columnIndex);
		}
		int width = component.getFontMetrics(
			component.getFont()
		).stringWidth(text) + insets.left + insets.right;
		column.setPreferredWidth(width);
		column.setMaxWidth(width);
//		column.setMinWidth(width);
	}
}