package com.vp.plugin.sample.modelviewchecker.ui;

import javax.swing.table.*;

import com.vp.plugin.model.*;

public class ModelViewTableModel extends AbstractTableModel {
	
	public static class Data {
		public final IModelElement model;
		private boolean _selected = true;
		
		public Data(IModelElement model) {
			this.model = model;
			this._selected = model.childCount() == 0;
		}
		
		public boolean isSelected() {
			return this._selected;
		}
	}
	
	public static final int
		COLUMN_MODEL_TYPE = 0, 
		COLUMN_MODEL_NAME = 1, 
		COLUMN_SELECTED = 2;
	
	private final Data[] _values;
	
	public ModelViewTableModel(IModelElement[] models) {
		int count = models == null ? 0 : models.length;
		this._values = new Data[count];
		for (int i = 0; i < count; i++) {
			this._values[i] = new Data(models[i]);
		}
	}
	
	public Data[] getValues() {
		return this._values;
	}

	public Class getColumnClass(int columnIndex) {
		if (columnIndex == COLUMN_MODEL_TYPE) {
			return String.class;
		}
		else if (columnIndex == COLUMN_MODEL_NAME) {
			return String.class;
		}
		else if (columnIndex == COLUMN_SELECTED) {
			return Boolean.class;
		}
		else {
			return String.class;
		}
	}

	public int getColumnCount() {
		return 3;
	}

	public String getColumnName(int columnIndex) {
		if (columnIndex == COLUMN_MODEL_TYPE) {
			return "Model Type";
		}
		if (columnIndex == COLUMN_MODEL_NAME) {
			return "Model Name";
		}
		else if (columnIndex == COLUMN_SELECTED) {
			return "Selected";
		}
		else {
			return "-";
		}
	}

	public int getRowCount() {
		return this._values.length;
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		Data data = this._values[rowIndex];
		if (columnIndex == COLUMN_MODEL_TYPE) {
			return data.model.getModelType();
		}
		else if (columnIndex == COLUMN_MODEL_NAME) {
			StringBuffer buffer = new StringBuffer(128);
			IModelElement model = data.model;
			buffer.append(model.getName());
			if (model.childCount() > 0) {
				buffer.append(" (has child)");
			}
			{
				IModelElement parent = model.getParent();
				while (parent != null) {
					buffer.insert(0, ".");
					buffer.insert(0, parent.getName());
					parent = parent.getParent();
				}
			}
			return buffer.toString();
		}
		else if (columnIndex == COLUMN_SELECTED) {
			return new Boolean(data._selected);
		}
		else {
			return null;
		}
	}

	public boolean isCellEditable(int rowIndex, int columnIndex) {
		return columnIndex == COLUMN_SELECTED;
	}

	public void setValueAt(Object value, int rowIndex, int columnIndex) {
		Data data = this._values[rowIndex];
		if (columnIndex == COLUMN_MODEL_NAME) {
		}
		else if (columnIndex == COLUMN_SELECTED) {
			if (value instanceof Boolean) {
				data._selected = ((Boolean) value).booleanValue();
			}
		}
		else {
		}
	}
}